@@ -69,8 +69,8 @@ static GList *icons_to_add = NULL;
 
 static GSList *image_menu_items = NULL;
 
-static GtkWidget *populate_menu_from_directory (GtkWidget         *menu,
-						MenuTreeDirectory *directory);
+static GtkWidget *populate_menu_from_directory (GtkWidget          *menu,
+						GMenuTreeDirectory *directory);
 
 static void panel_load_menu_image_deferred (GtkWidget   *image_menu_item,
 					    GtkIconSize  icon_size,
@@ -104,12 +104,12 @@ add_menu_separator (GtkWidget *menu)
 }
 
 static void
-activate_app_def (GtkWidget     *menuitem,
-		  MenuTreeEntry *entry)
+activate_app_def (GtkWidget      *menuitem,
+		  GMenuTreeEntry *entry)
 {
 	const char       *path;
 
-	path = menu_tree_entry_get_desktop_file_path (entry);
+	path = gmenu_tree_entry_get_desktop_file_path (entry);
 	panel_menu_item_activate_desktop_file (menuitem, path);
 }
 
@@ -187,7 +187,7 @@ menus_have_icons_changed (GConfClient *client,
 
 	value = gconf_entry_get_value (entry);
 
-	if (value->type == GCONF_VALUE_BOOL)
+	if (value != NULL && value->type == GCONF_VALUE_BOOL)
 		have_icons = gconf_value_get_bool (value);
 
 	list = g_list_copy (GTK_MENU_SHELL (menu)->children);
@@ -585,8 +585,8 @@ load_icons_handler_again:
 }
 
 static void
-add_app_to_panel (GtkWidget     *item,
-		  MenuTreeEntry *entry)
+add_app_to_panel (GtkWidget      *item,
+		  GMenuTreeEntry *entry)
 {
 	PanelWidget   *panel_widget;
 	PanelToplevel *toplevel;
@@ -601,24 +601,54 @@ add_app_to_panel (GtkWidget     *item,
 
 	panel_launcher_create (toplevel,
 			       position,
-			       menu_tree_entry_get_desktop_file_path (entry));
+			       gmenu_tree_entry_get_desktop_file_path (entry));
 }
 
+static void add_drawers_from_dir (GMenuTreeDirectory *directory,
+				  int                 pos,
+				  const char         *toplevel_id);
 
 static void
-add_drawers_from_dir (MenuTreeDirectory *directory,
-		      int                pos,
-		      const char        *toplevel_id)
+add_drawers_from_alias (GMenuTreeAlias *alias,
+			const char     *toplevel_id)
+{
+	GMenuTreeItem *aliased_item;
+
+	aliased_item = gmenu_tree_alias_get_item (alias);
+
+	switch (gmenu_tree_item_get_type (aliased_item)) {
+	case GMENU_TREE_ITEM_DIRECTORY:
+		add_drawers_from_dir (GMENU_TREE_DIRECTORY (aliased_item),
+				      G_MAXINT/2,
+				      toplevel_id);
+		break;
+
+	case GMENU_TREE_ITEM_ENTRY:
+		panel_launcher_create_with_id (toplevel_id,
+					       G_MAXINT/2,
+					       gmenu_tree_entry_get_desktop_file_path (GMENU_TREE_ENTRY (aliased_item)));
+		break;
+
+	default:
+		break;
+	}
+
+	gmenu_tree_item_unref (aliased_item);
+}
+
+static void
+add_drawers_from_dir (GMenuTreeDirectory *directory,
+		      int                 pos,
+		      const char         *toplevel_id)
 {
 	const char *name;
 	const char *icon;
-	GSList     *entries;
-	GSList     *subdirs;
+	GSList     *items;
 	GSList     *l;
 	char       *attached_toplevel_id;
 
-	name = menu_tree_directory_get_name (directory);
-	icon = menu_tree_directory_get_icon (directory);
+	name = gmenu_tree_directory_get_name (directory);
+	icon = gmenu_tree_directory_get_icon (directory);
 
 	attached_toplevel_id = panel_drawer_create_with_id (toplevel_id,
 							    pos,
@@ -628,42 +658,50 @@ add_drawers_from_dir (MenuTreeDirectory *directory,
 	if (!attached_toplevel_id)
 		return;
 
-	entries = menu_tree_directory_get_entries (directory);
-	for (l = entries; l; l = l->next) {
-		MenuTreeEntry *entry = l->data;
+	items = gmenu_tree_directory_get_contents (directory);
+	for (l = items; l; l = l->next) {
+		GMenuTreeItem *item = l->data;
 
-		panel_launcher_create_with_id (attached_toplevel_id,
-					       G_MAXINT/2,
-					       menu_tree_entry_get_desktop_file_path (entry));
+		switch (gmenu_tree_item_get_type (item)) {
+		case GMENU_TREE_ITEM_ENTRY:
+			panel_launcher_create_with_id (attached_toplevel_id,
+						       G_MAXINT/2,
+						       gmenu_tree_entry_get_desktop_file_path (GMENU_TREE_ENTRY (item)));
+			break;
 
-		menu_tree_entry_unref (entry);
+		case GMENU_TREE_ITEM_DIRECTORY:
+			add_drawers_from_dir (GMENU_TREE_DIRECTORY (item),
+					      G_MAXINT/2,
+					      attached_toplevel_id);
+			break;
+
+		case GMENU_TREE_ITEM_ALIAS:
+			add_drawers_from_alias (GMENU_TREE_ALIAS (item), attached_toplevel_id);
+			break;
+
+		default:
+			break;
+		}
+
+		gmenu_tree_item_unref (item);
 	}
-	g_slist_free (entries);
 
-	subdirs = menu_tree_directory_get_subdirs (directory);
-	for (l = subdirs; l; l = l->next) {
-		MenuTreeDirectory *subdir = l->data;
-
-		add_drawers_from_dir (subdir, G_MAXINT/2, attached_toplevel_id);
-
-		menu_tree_directory_unref (subdir);
-	}
-	g_slist_free (subdirs);
+	g_slist_free (items);
 
 	g_free (attached_toplevel_id);
 }
 
 static void
-add_menudrawer_to_panel (GtkWidget     *menuitem,
-			 MenuTreeEntry *entry)
+add_menudrawer_to_panel (GtkWidget      *menuitem,
+			 GMenuTreeEntry *entry)
 
 {
-	MenuTreeDirectory *directory;
+	GMenuTreeDirectory *directory;
 	PanelWidget       *panel;
 	PanelData         *pd;
 	int                insertion_pos;
 
-	directory = menu_tree_entry_get_parent (entry);
+	directory = gmenu_tree_item_get_parent (GMENU_TREE_ITEM (entry));
 
 	panel = menu_get_panel (menuitem);
 
@@ -674,19 +712,19 @@ add_menudrawer_to_panel (GtkWidget     *menuitem,
 			      insertion_pos,
 			      panel_profile_get_toplevel_id (panel->toplevel));
 
-	menu_tree_directory_unref (directory);
+	gmenu_tree_item_unref (directory);
 }
 
 static void
-add_menu_to_panel (GtkWidget     *menuitem,
-		   MenuTreeEntry *entry)
+add_menu_to_panel (GtkWidget      *menuitem,
+		   GMenuTreeEntry *entry)
 {
-	MenuTreeDirectory *directory;
-	PanelWidget       *panel;
-	PanelData         *pd;
-	int                insertion_pos;
-	char              *menu_path;
-	char              *menu_filename;
+	GMenuTreeDirectory *directory;
+	PanelWidget        *panel;
+	PanelData          *pd;
+	int                 insertion_pos;
+	char               *menu_path;
+	char               *menu_filename;
 
 	menu_filename = g_object_get_data (G_OBJECT (menuitem->parent),
 					   "panel-menu-tree-filename");
@@ -696,25 +734,25 @@ add_menu_to_panel (GtkWidget     *menuitem,
 		return;
 	}
 
-	directory = menu_tree_entry_get_parent (entry);
+	directory = gmenu_tree_item_get_parent (GMENU_TREE_ITEM (entry));
 
 	panel = menu_get_panel (menuitem);
 
 	pd = g_object_get_data (G_OBJECT (panel->toplevel), "PanelData");
 	insertion_pos = pd ? pd->insertion_pos : -1;
 
-	menu_path = menu_tree_directory_make_path (directory, NULL);
+	menu_path = gmenu_tree_directory_make_path (directory, NULL);
 
 	panel_menu_button_create (panel->toplevel,
 				  insertion_pos,
 				  menu_filename,
 				  menu_path,
 				  TRUE,
-				  menu_tree_directory_get_name (directory));
+				  gmenu_tree_directory_get_name (directory));
 
 	g_free (menu_path);
 
-	menu_tree_directory_unref (directory);
+	gmenu_tree_item_unref (directory);
 }
 
 /*most of this function stolen from the real gtk_menu_popup*/
@@ -773,13 +811,13 @@ static GtkWidget *
 create_item_context_menu (GtkWidget   *item,
 			  PanelWidget *panel_widget)
 {
-	MenuTreeEntry *entry;
-	GtkWidget     *parent;
-	GtkWidget     *menu;
-	GtkWidget     *submenu;
-	GtkWidget     *menuitem;
-	char          *menu_filename;
-	gboolean       id_lists_writable;
+	GMenuTreeEntry *entry;
+	GtkWidget      *parent;
+	GtkWidget      *menu;
+	GtkWidget      *submenu;
+	GtkWidget      *menuitem;
+	char           *menu_filename;
+	gboolean        id_lists_writable;
 
 	id_lists_writable = panel_profile_id_lists_are_writable ();
 
@@ -789,6 +827,7 @@ create_item_context_menu (GtkWidget   *item,
 
 	parent = item->parent;
 
+	menu_filename = NULL;
 	while (parent) {
 		menu_filename = g_object_get_data (G_OBJECT (parent),
 						   "panel-menu-tree-filename");
@@ -988,11 +1027,11 @@ drag_data_get_menu_cb (GtkWidget        *widget,
 		       GtkSelectionData *selection_data,
 		       guint             info,
 		       guint             time,
-		       MenuTreeEntry    *entry)
+		       GMenuTreeEntry   *entry)
 {
 	char *uri_list;
 
-	uri_list = g_strconcat (menu_tree_entry_get_desktop_file_path (entry),
+	uri_list = g_strconcat (gmenu_tree_entry_get_desktop_file_path (entry),
 				"\r\n",
 				NULL);
 
@@ -1174,9 +1213,9 @@ setup_internal_applet_drag (GtkWidget             *menuitem,
 static void
 submenu_to_display (GtkWidget *menu)
 {
-	MenuTree          *tree;
-	MenuTreeDirectory *directory;
-	const char        *menu_path;
+	GMenuTree          *tree;
+	GMenuTreeDirectory *directory;
+	const char         *menu_path;
 
 	if (!g_object_get_data (G_OBJECT (menu), "panel-menu-needs-loading"))
 		return;
@@ -1188,11 +1227,11 @@ submenu_to_display (GtkWidget *menu)
 		if (!(tree = g_object_get_data (G_OBJECT (menu), "panel-menu-tree")))
 			return;
 
-		directory = menu_tree_get_directory_from_path (tree, menu_path);
+		directory = gmenu_tree_get_directory_from_path (tree, menu_path);
 
 		g_object_set_data_full (G_OBJECT (menu), "panel-menu-tree-directory",
 					directory,
-					(GDestroyNotify) menu_tree_directory_unref);
+					(GDestroyNotify) gmenu_tree_item_unref);
 	}
 
 	if (directory)
@@ -1200,7 +1239,7 @@ submenu_to_display (GtkWidget *menu)
 }
 
 static GtkWidget *
-create_fake_menu (MenuTreeDirectory *directory)
+create_fake_menu (GMenuTreeDirectory *directory)
 {	
 	GtkWidget *menu;
 	
@@ -1208,8 +1247,8 @@ create_fake_menu (MenuTreeDirectory *directory)
 
 	g_object_set_data_full (G_OBJECT (menu),
 				"panel-menu-tree-directory",
-				menu_tree_directory_ref (directory),
-				(GDestroyNotify) menu_tree_directory_unref);
+				gmenu_tree_item_ref (directory),
+				(GDestroyNotify) gmenu_tree_item_unref);
 	
 	g_object_set_data (G_OBJECT (menu),
 			   "panel-menu-needs-loading",
@@ -1227,47 +1266,79 @@ create_fake_menu (MenuTreeDirectory *directory)
 	return menu;
 }
 
-static void
-create_submenu (GtkWidget         *menu,
-		MenuTreeDirectory *directory)
+static GtkWidget *
+create_submenu_entry (GtkWidget          *menu,
+		      GMenuTreeDirectory *directory)
 {
 	GtkWidget *menuitem;
-	GtkWidget *submenu;
 
 	menuitem = gtk_image_menu_item_new ();
 
-	g_object_set_data_full (G_OBJECT (menuitem),
-				"panel-menu-tree-directory",
-				menu_tree_directory_ref (directory),
-				(GDestroyNotify) menu_tree_directory_unref);
-
 	panel_load_menu_image_deferred (menuitem,
 					panel_menu_icon_get_size (),
 					NULL,
-					menu_tree_directory_get_icon (directory),
+					gmenu_tree_directory_get_icon (directory),
 					"gnome-fs-directory");
 
 	setup_menuitem (menuitem,
 			panel_menu_icon_get_size (),
 			NULL,
-			menu_tree_directory_get_name (directory),
+			gmenu_tree_directory_get_name (directory),
 			TRUE);
 
-	if (menu_tree_directory_get_comment (directory))
+	if (gmenu_tree_directory_get_comment (directory))
 		gtk_tooltips_set_tip (panel_tooltips,
 				      menuitem,
-				      menu_tree_directory_get_comment (directory),
+				      gmenu_tree_directory_get_comment (directory),
 				      NULL);
 
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 
-	submenu = create_fake_menu (directory);
-	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), submenu);
+	return menuitem;
 }
 
 static void
-create_menuitem (GtkWidget     *menu,
-		 MenuTreeEntry *entry)
+create_submenu (GtkWidget          *menu,
+		GMenuTreeDirectory *directory,
+		GMenuTreeDirectory *alias_directory)
+{
+	GtkWidget *menuitem;
+	GtkWidget *submenu;
+
+	if (alias_directory)
+		menuitem = create_submenu_entry (menu, alias_directory);
+	else
+		menuitem = create_submenu_entry (menu, directory);
+	
+	submenu = create_fake_menu (directory);
+
+	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem), submenu);
+}
+
+static void 
+create_header (GtkWidget       *menu,
+	       GMenuTreeHeader *header)
+{
+	GMenuTreeDirectory *directory;
+	GtkWidget          *menuitem;
+
+	directory = gmenu_tree_header_get_directory (header);
+	menuitem = create_submenu_entry (menu, directory);
+	gmenu_tree_item_unref (directory);
+
+	g_object_set_data_full (G_OBJECT (menuitem),
+				"panel-gmenu-tree.header",
+				gmenu_tree_item_ref (header),
+				(GDestroyNotify) gmenu_tree_item_unref);
+
+	g_signal_connect (menuitem, "activate",
+			  G_CALLBACK (gtk_false), NULL);
+}
+
+static void
+create_menuitem (GtkWidget          *menu,
+		 GMenuTreeEntry     *entry,
+		 GMenuTreeDirectory *alias_directory)
 {
 	GtkWidget  *menuitem;
 	
@@ -1275,29 +1346,38 @@ create_menuitem (GtkWidget     *menu,
 
 	g_object_set_data_full (G_OBJECT (menuitem),
 				"panel-menu-tree-entry",
-				menu_tree_entry_ref (entry),
-				(GDestroyNotify) menu_tree_entry_unref);
+				gmenu_tree_item_ref (entry),
+				(GDestroyNotify) gmenu_tree_item_unref);
+
+	if (alias_directory)
+		g_object_set_data_full (G_OBJECT (menuitem),
+					"panel-menu-tree-alias-directory",
+					gmenu_tree_item_ref (alias_directory),
+					(GDestroyNotify) gmenu_tree_item_unref);
 
 	panel_load_menu_image_deferred (menuitem,
 					panel_menu_icon_get_size (),
 					NULL,
-					menu_tree_entry_get_icon (entry),
+					alias_directory ? gmenu_tree_directory_get_icon (alias_directory) :
+							  gmenu_tree_entry_get_icon (entry),
 					NULL);
 
 	setup_menuitem (menuitem,
 			panel_menu_icon_get_size (),
 			NULL,
-			menu_tree_entry_get_name (entry),
+			alias_directory ? gmenu_tree_directory_get_name (alias_directory) :
+					  gmenu_tree_entry_get_name (entry),
 			TRUE);
 
-	if (menu_tree_entry_get_comment (entry))
+	if (gmenu_tree_entry_get_comment (entry))
 		gtk_tooltips_set_tip (panel_tooltips,
 				      menuitem,
-				      menu_tree_entry_get_comment (entry),
+				      alias_directory ? gmenu_tree_directory_get_comment (alias_directory) :
+							gmenu_tree_entry_get_comment (entry),
 				      NULL);
 
-	g_signal_connect (menuitem, "button_press_event",
-			  G_CALLBACK (menuitem_button_press_event), NULL);
+	g_signal_connect_after (menuitem, "button_press_event",
+				G_CALLBACK (menuitem_button_press_event), NULL);
 
 	if (!panel_lockdown_get_locked_down ()) {
 		static GtkTargetEntry menu_item_targets[] = {
@@ -1311,7 +1391,7 @@ create_menuitem (GtkWidget     *menu,
 
 		/* FIXME: waiting for bug #116577
 		gtk_drag_source_set_icon_name (GTK_WIDGET (button),
-					menu_tree_entry_get_icon (entry));
+					gmenu_tree_entry_get_icon (entry));
 		*/
 		g_signal_connect (menuitem, "drag_data_get",
 				  G_CALLBACK (drag_data_get_menu_cb), entry);
@@ -1326,8 +1406,36 @@ create_menuitem (GtkWidget     *menu,
 }
 
 static void
-handle_menu_tree_changed (MenuTree  *tree,
-			  GtkWidget *menu)
+create_menuitem_from_alias (GtkWidget      *menu,
+			    GMenuTreeAlias *alias)
+{
+	GMenuTreeItem *aliased_item;
+
+	aliased_item = gmenu_tree_alias_get_item (alias);
+
+	switch (gmenu_tree_item_get_type (aliased_item)) {
+	case GMENU_TREE_ITEM_DIRECTORY:
+		create_submenu (menu,
+				GMENU_TREE_DIRECTORY (aliased_item),
+				gmenu_tree_alias_get_directory (alias));
+		break;
+
+	case GMENU_TREE_ITEM_ENTRY:
+		create_menuitem (menu,
+				 GMENU_TREE_ENTRY (aliased_item),
+				 gmenu_tree_alias_get_directory (alias));
+		break;
+
+	default:
+		break;
+	}
+
+	gmenu_tree_item_unref (aliased_item);
+}
+
+static void
+handle_gmenu_tree_changed (GMenuTree *tree,
+			   GtkWidget *menu)
 {
 	while (GTK_MENU_SHELL (menu)->children)
                 gtk_widget_destroy (GTK_MENU_SHELL (menu)->children->data);
@@ -1346,11 +1454,11 @@ handle_menu_tree_changed (MenuTree  *tree,
 }
 
 static void
-remove_menu_tree_monitor (GtkWidget *menu,
-			  MenuTree  *tree)
+remove_gmenu_tree_monitor (GtkWidget *menu,
+			  GMenuTree  *tree)
 {
-	menu_tree_remove_monitor (tree,
-				  (MenuTreeChangedFunc) handle_menu_tree_changed,
+	gmenu_tree_remove_monitor (tree,
+				  (GMenuTreeChangedFunc) handle_gmenu_tree_changed,
 				  menu);
 }
 
@@ -1358,12 +1466,12 @@ GtkWidget *
 create_applications_menu (const char *menu_file,
 			  const char *menu_path)
 {
-	MenuTree  *tree;
+	GMenuTree *tree;
 	GtkWidget *menu;
 
 	menu = create_empty_menu ();
 
-	tree = menu_tree_lookup (menu_file);
+	tree = gmenu_tree_lookup (menu_file, GMENU_TREE_FLAGS_NONE);
 
 	g_object_set_data_full (G_OBJECT (menu),
 				"panel-menu-tree-filename",
@@ -1372,8 +1480,8 @@ create_applications_menu (const char *menu_file,
 
 	g_object_set_data_full (G_OBJECT (menu),
 				"panel-menu-tree",
-				menu_tree_ref (tree),
-				(GDestroyNotify) menu_tree_unref);
+				gmenu_tree_ref (tree),
+				(GDestroyNotify) gmenu_tree_unref);
 
 	g_object_set_data_full (G_OBJECT (menu),
 				"panel-menu-tree-path",
@@ -1393,57 +1501,67 @@ create_applications_menu (const char *menu_file,
 	g_signal_connect (menu, "button_press_event",
 			  G_CALLBACK (menu_dummy_button_press_event), NULL);
 
-	menu_tree_add_monitor (tree,
-			       (MenuTreeChangedFunc) handle_menu_tree_changed,
+	gmenu_tree_add_monitor (tree,
+			       (GMenuTreeChangedFunc) handle_gmenu_tree_changed,
 			       menu);
 	g_signal_connect (menu, "destroy",
-			  G_CALLBACK (remove_menu_tree_monitor), tree);
+			  G_CALLBACK (remove_gmenu_tree_monitor), tree);
 
-	menu_tree_unref (tree);
+	gmenu_tree_unref (tree);
 
 	return menu;
 }
 
 static GtkWidget *
-populate_menu_from_directory (GtkWidget         *menu,
-			      MenuTreeDirectory *directory)
+populate_menu_from_directory (GtkWidget          *menu,
+			      GMenuTreeDirectory *directory)
 {	
-	GSList   *subdirs;
-	GSList   *entries;
 	GSList   *l;
+	GSList   *items;
 	gboolean  add_separator;
 
 	add_separator = (GTK_MENU_SHELL (menu)->children != NULL);
 
-	subdirs = menu_tree_directory_get_subdirs (directory);
-	for (l = subdirs; l; l = l->next) {
-		MenuTreeDirectory *subdir = l->data;
+	items = gmenu_tree_directory_get_contents (directory);
 
-		if (add_separator) {
+	for (l = items; l; l = l->next) {
+		GMenuTreeItem *item = l->data;
+
+		if (add_separator ||
+		    gmenu_tree_item_get_type (item) == GMENU_TREE_ITEM_SEPARATOR) {
 			add_menu_separator (menu);
 			add_separator = FALSE;
 		}
 
-		create_submenu (menu, subdir);
+		switch (gmenu_tree_item_get_type (item)) {
+		case GMENU_TREE_ITEM_DIRECTORY:
+			create_submenu (menu, GMENU_TREE_DIRECTORY (item), NULL);
+			break;
 
-		menu_tree_directory_unref (subdir);
-	}
-	g_slist_free (subdirs);
+		case GMENU_TREE_ITEM_ENTRY:
+			create_menuitem (menu, GMENU_TREE_ENTRY (item), NULL);
+			break;
 
-	entries = menu_tree_directory_get_entries (directory);
-	for (l = entries; l; l = l->next) {
-		MenuTreeEntry *entry = l->data;
+		case GMENU_TREE_ITEM_SEPARATOR :
+			/* already added */
+			break;
 
-		if (add_separator) {
-			add_menu_separator (menu);
-			add_separator = FALSE;
+		case GMENU_TREE_ITEM_ALIAS:
+			create_menuitem_from_alias (menu, GMENU_TREE_ALIAS (item));
+			break;
+
+		case GMENU_TREE_ITEM_HEADER:
+			create_header (menu, GMENU_TREE_HEADER (item));
+			break;
+
+		default:
+			break;
 		}
 
-		create_menuitem (menu, entry);
-
-		menu_tree_entry_unref (entry);
+		gmenu_tree_item_unref (item);
 	}
-	g_slist_free (entries);
+
+	g_slist_free (items);
 
 	return menu;
 }
@@ -1480,6 +1598,7 @@ main_menu_append (GtkWidget   *main_menu,
 
 	children = gtk_container_get_children (GTK_CONTAINER (main_menu));
 
+	add_separator = FALSE;
 	if (children != NULL) {
 		while (children->next != NULL)
 			children = children->next;
@@ -1499,12 +1618,6 @@ main_menu_append (GtkWidget   *main_menu,
 	gtk_menu_shell_append (GTK_MENU_SHELL (main_menu), item);
 	gtk_widget_show (item);
 
-	item = panel_menu_items_create_action_item (PANEL_ACTION_RUN);
-	if (item != NULL) {
-		add_menu_separator (main_menu);
-		gtk_menu_shell_append (GTK_MENU_SHELL (main_menu), item);
-	}
-
 	panel_menu_items_append_lock_logout (main_menu);
 }
 
