@@ -27,8 +27,7 @@
 #include "panel-profile.h"
 
 #include <string.h>
-#include <libgnome/gnome-i18n.h>
-#include <pango/pango-attributes.h>
+#include <glib/gi18n.h>
 
 #include "applet.h"
 #include "panel-compatibility.h"
@@ -68,8 +67,6 @@ typedef void        (*PanelProfileLoadFunc)    (GConfClient       *client,
 						const char        *id);
 typedef void        (*PanelProfileDestroyFunc) (const char        *id);
 
-static char *current_profile = NULL;
-
 static GConfEnumStringPair panel_orientation_map [] = {
 	{ PANEL_ORIENTATION_TOP,    "top"    },
 	{ PANEL_ORIENTATION_BOTTOM, "bottom" },
@@ -105,12 +102,6 @@ static GQuark toplevel_id_quark = 0;
 static GQuark queued_changes_quark = 0;
 static GQuark commit_timeout_quark = 0;
 
-const char *
-panel_profile_get_name (void)
-{
-	return current_profile;
-}
-
 gboolean
 panel_profile_map_orientation_string (const char       *str,
 				      PanelOrientation *orientation)
@@ -243,14 +234,12 @@ panel_profile_find_new_id (PanelGConfKeyType type)
 	GConfClient *client;
 	GSList      *l, *existing_ids;
 	const char  *key;
-	const char  *profile;
 	char        *retval = NULL;
 	char        *prefix;
 	char        *dir;
 	int          i;
 
 	client  = panel_gconf_get_client ();
-	profile = panel_profile_get_name ();
 
 	switch (type) {
 	case PANEL_GCONF_TOPLEVELS:
@@ -271,7 +260,7 @@ panel_profile_find_new_id (PanelGConfKeyType type)
 		break;
 	}
 
-	key = panel_gconf_sprintf (PANEL_CONFIG_DIR "/%s/%s", profile, dir);
+	key = panel_gconf_sprintf (PANEL_CONFIG_DIR "/%s", dir);
 	existing_ids = gconf_client_all_dirs (client, key, NULL);
 
 	for (i = 0; !retval; i++) {
@@ -345,7 +334,7 @@ panel_profile_get_toplevel_key (PanelToplevel *toplevel,
 
 	id = panel_profile_get_toplevel_id (toplevel);
 
-	return panel_gconf_full_key (PANEL_GCONF_TOPLEVELS, current_profile, id, key);
+	return panel_gconf_full_key (PANEL_GCONF_TOPLEVELS, id, key);
 }
 
 #define TOPLEVEL_IS_WRITABLE_FUNC(k, p, s)                            \
@@ -402,13 +391,7 @@ void
 panel_profile_set_background_color (PanelToplevel *toplevel,
 				    PanelColor    *color)
 {
-	PangoColor pango_color;
-
-	pango_color.red   = color->gdk.red;
-	pango_color.green = color->gdk.green;
-	pango_color.blue  = color->gdk.blue;
-
-	panel_profile_set_background_pango_color (toplevel, &pango_color);
+	panel_profile_set_background_gdk_color (toplevel, &color->gdk);
 	panel_profile_set_background_opacity (toplevel, color->alpha);
 }
 
@@ -416,23 +399,15 @@ void
 panel_profile_get_background_color (PanelToplevel *toplevel,
 				    PanelColor    *color)
 {
-	PangoColor pango_color;
-	guint16    opacity;
-
-	panel_profile_get_background_pango_color (toplevel, &pango_color);
-	opacity = panel_profile_get_background_opacity (toplevel);
-
-	color->gdk.red   = pango_color.red;
-	color->gdk.green = pango_color.green;
-	color->gdk.blue  = pango_color.blue;
-	color->alpha     = opacity;
+	panel_profile_get_background_gdk_color (toplevel, &(color->gdk));
+	color->alpha = panel_profile_get_background_opacity (toplevel);
 }
 
 TOPLEVEL_IS_WRITABLE_FUNC ("background/color", background, color)
 
 void
-panel_profile_set_background_pango_color (PanelToplevel *toplevel,
-					  PangoColor    *pango_color)
+panel_profile_set_background_gdk_color (PanelToplevel *toplevel,
+					GdkColor      *gdk_color)
 {
 	GConfClient *client;
 	const char  *key;
@@ -441,9 +416,9 @@ panel_profile_set_background_pango_color (PanelToplevel *toplevel,
 	client = panel_gconf_get_client ();
 
 	color_str = g_strdup_printf ("#%02x%02x%02x",
-				     pango_color->red   / 256,
-				     pango_color->green / 256,
-				     pango_color->blue  / 256);
+				     gdk_color->red   / 256,
+				     gdk_color->green / 256,
+				     gdk_color->blue  / 256);
 
 	key = panel_profile_get_toplevel_key (toplevel, "background/color");
 	gconf_client_set_string (client, key, color_str, NULL);
@@ -452,8 +427,8 @@ panel_profile_set_background_pango_color (PanelToplevel *toplevel,
 }
 
 void
-panel_profile_get_background_pango_color (PanelToplevel *toplevel,
-					  PangoColor    *pango_color)
+panel_profile_get_background_gdk_color (PanelToplevel *toplevel,
+					GdkColor      *gdk_color)
 {
 	GConfClient *client;
 	const char  *key;
@@ -463,10 +438,10 @@ panel_profile_get_background_pango_color (PanelToplevel *toplevel,
 
 	key = panel_profile_get_toplevel_key (toplevel, "background/color");
 	color_str = gconf_client_get_string (client, key, NULL);
-	if (!color_str || !pango_color_parse (pango_color, color_str)) {
-		pango_color->red   = 0;
-		pango_color->green = 0;
-		pango_color->blue  = 0;
+	if (!color_str || !gdk_color_parse (color_str, gdk_color)) {
+		gdk_color->red   = 0;
+		gdk_color->green = 0;
+		gdk_color->blue  = 0;
 	}
 
 	g_free (color_str);
@@ -655,7 +630,7 @@ panel_profile_get_attached_object_key (PanelToplevel *toplevel,
 	if (!id)
 		return NULL;
 
-	return panel_gconf_full_key (PANEL_GCONF_OBJECTS, current_profile, id, key);
+	return panel_gconf_full_key (PANEL_GCONF_OBJECTS, id, key);
 }
 
 void
@@ -784,7 +759,6 @@ get_background_color (GConfClient *client,
 		      const char  *toplevel_dir,
 		      PanelColor  *color)
 {
-	PangoColor  pango_color;
 	GError     *error;
 	const char *key;
 	char       *color_str;
@@ -792,17 +766,14 @@ get_background_color (GConfClient *client,
 	error = NULL;
 	key = panel_gconf_sprintf ("%s/background/color", toplevel_dir);
 	color_str = gconf_client_get_string (client, key, &error);
-	color->gdk.red   = 0;
-	color->gdk.green = 0;
-	color->gdk.blue  = 0;
 	if (error) {
 		g_warning (_("Error reading GConf string value '%s': %s"),
 			   key, error->message);
 		g_error_free (error);
-	} else if (color_str && pango_color_parse (&pango_color, color_str)) {
-		color->gdk.red   = pango_color.red;
-		color->gdk.green = pango_color.green;
-		color->gdk.blue  = pango_color.blue;
+	} else if (!color_str || !gdk_color_parse (color_str, &(color->gdk))) {
+		color->gdk.red   = 0;
+		color->gdk.green = 0;
+		color->gdk.blue  = 0;
 	}
 
 	g_free (color_str);
@@ -975,7 +946,7 @@ panel_profile_queue_toplevel_location_change (PanelToplevel          *toplevel,
 	static void                                                               \
 	panel_profile_toplevel_##c##_changed (PanelToplevel *toplevel)            \
 	{                                                                         \
-		ToplevelLocationChange change = { 0, };                           \
+		ToplevelLocationChange change = { NULL };                           \
 		change.c##_changed = TRUE;                                        \
 		change.c = panel_toplevel_get_##c (toplevel);                     \
 		panel_profile_queue_toplevel_location_change (toplevel, &change); \
@@ -991,7 +962,7 @@ TOPLEVEL_LOCATION_CHANGED_HANDLER(y_centered)
 	static void                                                               \
 	panel_profile_toplevel_##c##_changed (PanelToplevel *toplevel)            \
 	{                                                                         \
-		ToplevelLocationChange change = { 0, };                           \
+		ToplevelLocationChange change = { NULL };                           \
 		int                    x, y;                                      \
 		change.c##_changed = TRUE;                                        \
 		panel_toplevel_get_position (toplevel, &x, &y);                   \
@@ -1005,7 +976,7 @@ TOPLEVEL_POSITION_CHANGED_HANDLER(y)
 static void
 panel_profile_toplevel_screen_changed (PanelToplevel *toplevel)
 {
-	ToplevelLocationChange change = { 0, };
+	ToplevelLocationChange change = { NULL };
 
 	change.screen_changed = TRUE;
 	change.screen = gtk_window_get_screen (GTK_WINDOW (toplevel));
@@ -1194,13 +1165,13 @@ panel_profile_background_change_notify (GConfClient   *client,
 		}
 	} else if (!strcmp (key, "color")) {
 		if (value->type == GCONF_VALUE_STRING) {
-			PangoColor  pango_color;
+			GdkColor    gdk_color;
 			const char *str;
 
 			str = gconf_value_get_string (value);
 
-			if (pango_color_parse (&pango_color, str))
-				panel_background_set_pango_color (background, &pango_color);
+			if (gdk_color_parse (str, &gdk_color))
+				panel_background_set_gdk_color (background, &gdk_color);
 		}
 	} else if (!strcmp (key, "opacity")) {
 		if (value->type == GCONF_VALUE_INT)
@@ -1250,12 +1221,10 @@ panel_profile_toplevel_notify_add (PanelToplevel         *toplevel,
 	client = panel_gconf_get_client ();
 
 	if (!key)
-		tmp = panel_gconf_sprintf (PANEL_CONFIG_DIR "/%s/toplevels/%s",
-					   current_profile,
+		tmp = panel_gconf_sprintf (PANEL_CONFIG_DIR "/toplevels/%s",
 					   panel_profile_get_toplevel_id (toplevel));
 	else
-		tmp = panel_gconf_sprintf (PANEL_CONFIG_DIR "/%s/toplevels/%s/%s",
-					   current_profile,
+		tmp = panel_gconf_sprintf (PANEL_CONFIG_DIR "/toplevels/%s/%s",
 					   panel_profile_get_toplevel_id (toplevel),
 					   key);
 
@@ -1264,12 +1233,57 @@ panel_profile_toplevel_notify_add (PanelToplevel         *toplevel,
 	return retval;
 }
 
+static void
+panel_profile_save_id_list (PanelGConfKeyType  type,
+			    GSList            *list,
+			    gboolean           resave)
+{
+	GConfClient *client;
+	const char  *key;
+	const char  *id_list;
+
+	g_assert (!(resave && list != NULL));
+
+	client = panel_gconf_get_client ();
+
+	id_list = panel_gconf_key_type_to_id_list (type);
+
+	key = panel_gconf_general_key (id_list);
+	if (resave)
+		list = gconf_client_get_list (client, key, GCONF_VALUE_STRING, NULL);
+	else {
+		/* Make sure the elements in the list appear only once. We only
+		 * do it when we save a list with new elements. */
+		list = panel_g_slist_make_unique (list,
+						  (GCompareFunc) strcmp,
+						  TRUE);
+	}
+
+	gconf_client_set_list (client, key, GCONF_VALUE_STRING, list, NULL);
+
+	g_slist_foreach (list, (GFunc) g_free, NULL);
+	g_slist_free (list);
+}
+
+static inline void
+panel_profile_save_other_id_lists (PanelGConfKeyType type)
+{
+	if (type != PANEL_GCONF_TOPLEVELS)
+		panel_profile_save_id_list (PANEL_GCONF_TOPLEVELS, NULL, TRUE);
+
+	if (type != PANEL_GCONF_OBJECTS)
+		panel_profile_save_id_list (PANEL_GCONF_OBJECTS, NULL, TRUE);
+
+	if (type != PANEL_GCONF_APPLETS)
+		panel_profile_save_id_list (PANEL_GCONF_APPLETS, NULL, TRUE);
+}
+
 void
 panel_profile_add_to_list (PanelGConfKeyType  type,
 			   const char        *id)
 {
 	GConfClient *client;
-	GSList      *list, *l;
+	GSList      *list;
 	const char  *key;
 	const char  *id_list;
 	char        *new_id;
@@ -1278,21 +1292,15 @@ panel_profile_add_to_list (PanelGConfKeyType  type,
 
 	id_list = panel_gconf_key_type_to_id_list (type);
 
-	key = panel_gconf_general_key (current_profile, id_list);
+	key = panel_gconf_general_key (id_list);
 	list = gconf_client_get_list (client, key, GCONF_VALUE_STRING, NULL);
 
 	new_id = id ? g_strdup (id) : panel_profile_find_new_id (type);
 
 	list = g_slist_append (list, new_id);
 
-	key = panel_gconf_general_key (current_profile, id_list);
-	gconf_client_set_list (client, key, GCONF_VALUE_STRING, list, NULL);
-
-	for (l = list; l; l = l->next) {
-		g_free (l->data);
-		l->data = NULL;
-	}
-	g_slist_free (list);
+	panel_profile_save_id_list (type, list, FALSE);
+	panel_profile_save_other_id_lists (type);
 }
 
 void
@@ -1308,26 +1316,31 @@ panel_profile_remove_from_list (PanelGConfKeyType  type,
 
 	id_list = panel_gconf_key_type_to_id_list (type);
 
-	key = panel_gconf_general_key (current_profile, id_list);
+	key = panel_gconf_general_key (id_list);
 	list = gconf_client_get_list (client, key, GCONF_VALUE_STRING, NULL);
 
-	for (l = list; l; l = l->next)
-		if (!strcmp (id, l->data))
-			break;
-	if (l) {
-		g_free (l->data);
-		list = g_slist_delete_link (list, l);
+	/* Remove all occurrence of id and not just the first. We're more solid
+	 * this way (see bug #137308 for example). */
+	l = list;
+	while (l) {
+		GSList *next;
+
+		next = l->next;
+
+		if (!strcmp (id, l->data)) {
+			g_free (l->data);
+			list = g_slist_delete_link (list, l);
+		}
+
+		l = next;
 	}
 
-	gconf_client_set_list (client, key, GCONF_VALUE_STRING, list, NULL);
-
-	for (l = list; l; l = l->next)
-		g_free (l->data);
-	g_slist_free (list);
+	panel_profile_save_id_list (type, list, FALSE);
+	panel_profile_save_other_id_lists (type);
 }
 
-gboolean
-panel_profile_list_is_writable (PanelGConfKeyType type)
+static gboolean
+panel_profile_id_list_is_writable (PanelGConfKeyType type)
 {
 	GConfClient *client;
 	const char  *key;
@@ -1337,10 +1350,19 @@ panel_profile_list_is_writable (PanelGConfKeyType type)
 
 	id_list = panel_gconf_key_type_to_id_list (type);
 
-	key = panel_gconf_general_key (current_profile, id_list);
+	key = panel_gconf_general_key (id_list);
 	return gconf_client_key_is_writable (client, key, NULL);
 }
 
+gboolean
+panel_profile_id_lists_are_writable (void)
+{
+  return
+    panel_profile_id_list_is_writable (PANEL_GCONF_TOPLEVELS) &&
+    panel_profile_id_list_is_writable (PANEL_GCONF_APPLETS)   &&
+    panel_profile_id_list_is_writable (PANEL_GCONF_OBJECTS);
+}
+
 static gboolean
 panel_profile_find_empty_spot (GdkScreen *screen,
 			       PanelOrientation *orientation,
@@ -1416,18 +1438,18 @@ panel_profile_create_toplevel (GdkScreen *screen)
 
 	id = panel_profile_find_new_id (PANEL_GCONF_TOPLEVELS);
 
-	dir = g_strdup_printf (PANEL_CONFIG_DIR "/%s/toplevels/%s", current_profile, id);
+	dir = g_strdup_printf (PANEL_CONFIG_DIR "/toplevels/%s", id);
 	panel_gconf_associate_schemas_in_dir (client, dir, PANEL_SCHEMAS_DIR "/toplevels");
 	g_free (dir);
 
-	key = panel_gconf_full_key (PANEL_GCONF_TOPLEVELS, current_profile, id, "screen");
+	key = panel_gconf_full_key (PANEL_GCONF_TOPLEVELS, id, "screen");
 	gconf_client_set_int (client, key, gdk_screen_get_number (screen), NULL);
 
 	if (panel_profile_find_empty_spot (screen, &orientation, &monitor)) {
-		key = panel_gconf_full_key (PANEL_GCONF_TOPLEVELS, current_profile, id, "monitor");
+		key = panel_gconf_full_key (PANEL_GCONF_TOPLEVELS, id, "monitor");
 		gconf_client_set_int (client, key, monitor, NULL);
 
-		key = panel_gconf_full_key (PANEL_GCONF_TOPLEVELS, current_profile, id, "orientation");
+		key = panel_gconf_full_key (PANEL_GCONF_TOPLEVELS, id, "orientation");
 		gconf_client_set_string (client, key, panel_profile_map_orientation (orientation), NULL);
 	}
 	
@@ -1446,15 +1468,14 @@ panel_profile_delete_toplevel_objects (const char        *toplevel_id,
 
 	client = panel_gconf_get_client ();
 
-	key = panel_gconf_general_key (current_profile,
-				       panel_gconf_key_type_to_id_list (key_type));
+	key = panel_gconf_general_key (panel_gconf_key_type_to_id_list (key_type));
 	list = gconf_client_get_list (client, key, GCONF_VALUE_STRING, NULL);
 
 	for (l = list; l; l = l->next) {
 		char *id = l->data;
 		char *parent_toplevel_id;
 
-		key = panel_gconf_full_key (key_type, current_profile, id, "toplevel_id");
+		key = panel_gconf_full_key (key_type, id, "toplevel_id");
 		parent_toplevel_id = gconf_client_get_string (client, key, NULL);
 
 		if (parent_toplevel_id && !strcmp (toplevel_id, parent_toplevel_id)) {
@@ -1467,8 +1488,7 @@ panel_profile_delete_toplevel_objects (const char        *toplevel_id,
 	}
 	g_slist_free (list);
 
-	key = panel_gconf_general_key (current_profile,
-				       panel_gconf_key_type_to_id_list (key_type));
+	key = panel_gconf_general_key (panel_gconf_key_type_to_id_list (key_type));
 	gconf_client_set_list (client, key, GCONF_VALUE_STRING, new_list, NULL);
 
 	for (l = new_list; l; l = l->next)
@@ -1555,6 +1575,8 @@ panel_profile_load_toplevel (GConfClient       *client,
 			      NULL);
 
 	if (!(screen = get_toplevel_screen (client, toplevel_dir))) {
+		gconf_client_remove_dir (client, key, NULL);
+		gconf_client_remove_dir (client, toplevel_dir, NULL);
 		g_free (toplevel_dir);
 		return NULL;
 	}
@@ -1717,25 +1739,24 @@ panel_profile_prepare_object_with_id (PanelObjectType  object_type,
 
 	id = panel_profile_find_new_id (key_type);
 
-	dir = g_strdup_printf (PANEL_CONFIG_DIR "/%s/%s/%s",
-			       current_profile,
+	dir = g_strdup_printf (PANEL_CONFIG_DIR "/%s/%s",
 			       (key_type == PANEL_GCONF_APPLETS) ? "applets" : "objects",
 			       id);
 	panel_gconf_associate_schemas_in_dir (client, dir, PANEL_SCHEMAS_DIR "/objects");
 
-	key = panel_gconf_full_key (key_type, current_profile, id, "object_type");
+	key = panel_gconf_full_key (key_type, id, "object_type");
 	gconf_client_set_string (client,
 				 key,
 				 gconf_enum_to_string (panel_object_type_map, object_type),
 				 NULL);
 
-	key = panel_gconf_full_key (key_type, current_profile, id, "toplevel_id");
+	key = panel_gconf_full_key (key_type, id, "toplevel_id");
 	gconf_client_set_string (client, key, toplevel_id, NULL);
 
-	key = panel_gconf_full_key (key_type, current_profile, id, "position");
+	key = panel_gconf_full_key (key_type, id, "position");
 	gconf_client_set_int (client, key, position, NULL);
 
-	key = panel_gconf_full_key (key_type, current_profile, id, "panel_right_stick");
+	key = panel_gconf_full_key (key_type, id, "panel_right_stick");
 	gconf_client_set_bool (client, key, right_stick, NULL);
 
 	g_free (dir);
@@ -1795,6 +1816,8 @@ panel_profile_load_object (GConfClient       *client,
         
 	if (!panel_profile_map_object_type_string (type_string, &object_type)) {
 		g_free (type_string);
+		g_free (object_dir);
+		gconf_client_remove_dir (client, object_dir, NULL);
 		return;
 	}
 	
@@ -1857,13 +1880,13 @@ panel_profile_delete_dir (GConfClient       *client,
 	}
 
 	if (type == PANEL_GCONF_TOPLEVELS) {
-		key = panel_gconf_sprintf (PANEL_CONFIG_DIR "/%s/%s/%s/background",
-					   current_profile, type_str, id);
+		key = panel_gconf_sprintf (PANEL_CONFIG_DIR "/%s/%s/background",
+					   type_str, id);
 		gconf_client_remove_dir (client, key, NULL);
 	}
 
-	key = panel_gconf_sprintf (PANEL_CONFIG_DIR "/%s/%s/%s",
-				   current_profile, type_str, id);
+	key = panel_gconf_sprintf (PANEL_CONFIG_DIR "/%s/%s",
+				   type_str, id);
 	gconf_client_remove_dir (client, key, NULL);
 
 	gconf_client_recursive_unset (client,
@@ -1925,7 +1948,6 @@ panel_profile_load_added_ids (GConfClient            *client,
 {
 	GSList *added_ids = NULL;
 	GSList *l;
-	char   *profile_dir = NULL;
 
 	for (l = id_list; l; l = l->next) {
 		const char *id = gconf_value_get_string (l->data);
@@ -1935,18 +1957,14 @@ panel_profile_load_added_ids (GConfClient            *client,
 			added_ids = g_slist_prepend (added_ids, g_strdup (id));
 	}
 
-	profile_dir = gconf_concat_dir_and_key (PANEL_CONFIG_DIR, current_profile);
-
 	for (l = added_ids; l; l = l->next) {
-		load_handler (client, profile_dir, type, l->data);
+		load_handler (client, PANEL_CONFIG_DIR, type, l->data);
 
 		g_free (l->data);
 		l->data = NULL;
 	}
 
 	g_slist_free (added_ids);
-
-	g_free (profile_dir);
 }
 
 static void
@@ -1999,7 +2017,10 @@ panel_profile_toplevel_id_list_notify (GConfClient *client,
 		return;
 	}
 
-	toplevel_ids = gconf_value_get_list (value);
+	toplevel_ids = g_slist_copy (gconf_value_get_list (value));
+	toplevel_ids = panel_g_slist_make_unique (toplevel_ids,
+						  panel_gconf_value_strcmp,
+						  FALSE);
 
 	existing_toplevels = NULL;
 	for (l = panel_toplevel_list_toplevels (); l; l = l->next) {
@@ -2028,6 +2049,7 @@ panel_profile_toplevel_id_list_notify (GConfClient *client,
 					  (PanelProfileDestroyFunc) panel_profile_destroy_toplevel);
 
 	g_slist_free (existing_toplevels);
+	g_slist_free (toplevel_ids);
 }
 
 static void
@@ -2051,7 +2073,10 @@ panel_profile_object_id_list_notify (GConfClient *client,
 		return;
 	}
 
-	object_ids = gconf_value_get_list (value);
+	object_ids = g_slist_copy (gconf_value_get_list (value));
+	object_ids = panel_g_slist_make_unique (object_ids,
+						panel_gconf_value_strcmp,
+						FALSE);
 
 	existing_applets = panel_applet_list_applets ();
 
@@ -2079,6 +2104,7 @@ panel_profile_object_id_list_notify (GConfClient *client,
 					  (PanelProfileDestroyFunc) panel_profile_destroy_object);
 
 	g_slist_free (sublist);
+	g_slist_free (object_ids);
 
 	panel_applet_load_queued_applets ();
 }
@@ -2105,6 +2131,10 @@ panel_profile_load_list (GConfClient           *client,
 				 NULL, NULL);
 
 	list = gconf_client_get_list (client, key, GCONF_VALUE_STRING, NULL);
+	list = panel_g_slist_make_unique (list,
+					  (GCompareFunc) strcmp,
+					  TRUE);
+
 	for (l = list; l; l = l->next) {
 		load_handler (client, profile_dir, type, l->data);
 
@@ -2184,7 +2214,7 @@ panel_profile_append_new_ids (GConfClient       *client,
 
 	id_list = panel_gconf_key_type_to_id_list (type);
 
-	key = panel_gconf_general_key (current_profile, id_list);
+	key = panel_gconf_general_key (id_list);
 	list = gconf_client_get_list (client, key, GCONF_VALUE_STRING, NULL);
 
 	for (l = new_ids; l; l = l->next)
@@ -2217,7 +2247,7 @@ panel_profile_copy_default_objects_for_screen (GConfClient       *client,
 
 		next = l->next;
 
-		key = panel_gconf_full_key (type, current_profile, object_id, "toplevel_id");
+		key = panel_gconf_full_key (type, object_id, "toplevel_id");
 		toplevel_id = gconf_client_get_string (client, key, NULL);
 		if (!toplevel_id) {
 			new_objects = g_slist_remove_link (new_objects, l);
@@ -2279,7 +2309,6 @@ panel_profile_load_defaults_on_screen (GConfClient *client,
 		const char *key;
 
 		key = panel_gconf_full_key (PANEL_GCONF_TOPLEVELS,
-					    current_profile,
 					    toplevel_id,
 					    "screen");
 		gconf_client_set_int (client, key, screen_n, NULL);
@@ -2328,51 +2357,37 @@ panel_profile_ensure_toplevel_per_screen (GConfClient *client,
 }
 
 void
-panel_profile_load (char *profile_name)
+panel_profile_load (void)
 {
 	GConfClient *client;
-	char        *dir;
-	const char  *key;
-
-	if (current_profile) {
-		g_warning ("Changing profiles not yet implemented\n");
-		return;
-	}
-
-	current_profile = profile_name ? profile_name : "default";
 
 	client  = panel_gconf_get_client ();
 
-	dir = gconf_concat_dir_and_key (PANEL_CONFIG_DIR, current_profile);
-	if (!gconf_client_dir_exists (client, dir, NULL))
-		panel_gconf_copy_dir (client, PANEL_DEFAULTS_DIR, dir);
+	panel_compatibility_maybe_copy_old_config (client);
 
 	panel_compatibility_migrate_panel_id_list (client);
 
-	key = panel_gconf_sprintf ("%s/general", dir);
-	gconf_client_add_dir (client, key, GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
+	gconf_client_add_dir (client, PANEL_CONFIG_DIR "/general", GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
 
 	panel_profile_load_list (client,
-				 dir,
+				 PANEL_CONFIG_DIR,
 				 PANEL_GCONF_TOPLEVELS,
 				 panel_profile_load_and_show_toplevel,
 				 (GConfClientNotifyFunc) panel_profile_toplevel_id_list_notify);
 	panel_profile_load_list (client,
-				 dir,
+				 PANEL_CONFIG_DIR,
 				 PANEL_GCONF_OBJECTS,
 				 panel_profile_load_object,
 				 (GConfClientNotifyFunc) panel_profile_object_id_list_notify);
 	panel_profile_load_list (client,
-				 dir,
+				 PANEL_CONFIG_DIR,
 				 PANEL_GCONF_APPLETS,
 				 panel_profile_load_object,
 				 (GConfClientNotifyFunc) panel_profile_object_id_list_notify);
 
-	panel_profile_ensure_toplevel_per_screen (client, dir);
+	panel_profile_ensure_toplevel_per_screen (client, PANEL_CONFIG_DIR);
 
 	panel_applet_load_queued_applets ();
-
-	g_free (dir);
 }
 
 static gboolean
@@ -2384,7 +2399,7 @@ get_program_listing_setting (const char *setting)
 
 	client = panel_gconf_get_client ();
 
-	key = panel_gconf_general_key (current_profile, setting);
+	key = panel_gconf_general_key (setting);
 	retval = gconf_client_get_bool (client, key, NULL);
 
 	return retval;
@@ -2402,6 +2417,12 @@ panel_profile_get_enable_program_list (void)
 	return get_program_listing_setting ("enable_program_list");
 }
 
+gboolean
+panel_profile_get_enable_autocomplete (void)
+{
+	return get_program_listing_setting ("enable_autocomplete");
+}
+
 void
 panel_profile_set_show_program_list (gboolean show_program_list)
 {
@@ -2410,7 +2431,7 @@ panel_profile_set_show_program_list (gboolean show_program_list)
 
 	client = panel_gconf_get_client ();
 
-	key = panel_gconf_general_key (current_profile, "show_program_list");
+	key = panel_gconf_general_key ("show_program_list");
 	gconf_client_set_bool (client, key, show_program_list, NULL);
 }
 
@@ -2422,7 +2443,7 @@ panel_profile_is_writable_show_program_list (void)
 
 	client = panel_gconf_get_client ();
 
-	key = panel_gconf_general_key (current_profile, "show_program_list");
+	key = panel_gconf_general_key ("show_program_list");
 	return gconf_client_key_is_writable (client, key, NULL);
 }
 
