@@ -613,6 +613,7 @@ panel_applet_position_menu (GtkMenu   *menu,
 	    applet->priv->orient == PANEL_APPLET_ORIENT_DOWN) {
 		if (requisition.width < pointer_x)
 			menu_x += MIN (pointer_x, widget->allocation.width - requisition.width);
+		menu_x = MIN (menu_x, gdk_screen_get_width (screen) - requisition.width);
 
 		if (menu_y > gdk_screen_get_height (screen) / 2)
 			menu_y -= requisition.height;
@@ -621,6 +622,7 @@ panel_applet_position_menu (GtkMenu   *menu,
 	} else  {
 		if (requisition.height < pointer_y)
 			menu_y += MIN (pointer_y, widget->allocation.height - requisition.height);
+		menu_y = MIN (menu_y, gdk_screen_get_height (screen) - requisition.height);
 
 		if (menu_x > gdk_screen_get_width (screen) / 2)
 			menu_x -= requisition.width;
@@ -935,6 +937,10 @@ panel_applet_get_pixmap (PanelApplet     *applet,
 	if (!GTK_WIDGET_REALIZED (applet))
 		return NULL;
 
+	gc = gdk_gc_new (GDK_DRAWABLE (GTK_WIDGET (applet)->window));
+
+	g_return_val_if_fail (GDK_IS_GC (gc), NULL);
+
 	display = gdk_display_get_default ();
 	
 	pixmap = gdk_pixmap_lookup_for_display (display, xid);
@@ -950,10 +956,6 @@ panel_applet_get_pixmap (PanelApplet     *applet,
 
 	retval = gdk_pixmap_new (GTK_WIDGET (applet)->window, width, height, -1);
 
-	gc = gdk_gc_new (GDK_DRAWABLE (GTK_WIDGET (applet)->window));
-
-	g_return_val_if_fail (GDK_IS_GC (gc), NULL);
-
 	gdk_draw_drawable (GDK_DRAWABLE (retval),
 			   gc, 
 			   GDK_DRAWABLE (pixmap),
